PickerContryProvider class

Inheritance

Constructors

PickerContryProvider()

Properties

cont Country?
getter/setter pair
countryCodeList List<Country>
getter/setter pair
countryCodeListFilter List<Country>
getter/setter pair
debouncing Debouncer
final
formKey GlobalKey<FormState>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
height double
getter/setter pair
phoneLength int?
getter/setter pair
phoneNumber int?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scrollcontroller ScrollController
final
searchController TextEditingController
getter/setter pair
selectedCountryCode String
getter/setter pair
selectedCountryFlag String
getter/setter pair
validation String?
getter/setter pair

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
countryCodeToEmoji(String countryCode) String
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
filterCountryList(String search) → void
getPreSelectedCountryCode() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setCountry(Country? selectedCountry) → void
setPhoneLength(int length) → void
setValidations(String number) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited