Country class
Constructors
- Country({String? phoneCode, String? countryCode, int? e164Sc, bool? geographic, int? level, String? name, String? nameLocalized, String? example, String? displayName, String? fullExampleWithPlusSign, String? displayNameNoCountryCode, String? e164Key, int? phoneNumberLength})
-
Country.fromMap(Map<
String, dynamic> map) -
factory
Properties
- countryCode ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- displayNameNoCountryCode ↔ String?
-
getter/setter pair
- e164Key ↔ String?
-
getter/setter pair
- e164Sc ↔ int?
-
getter/setter pair
- example ↔ String?
-
getter/setter pair
- fullExampleWithPlusSign ↔ String?
-
getter/setter pair
- geographic ↔ bool?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- level ↔ int?
-
getter/setter pair
- name ↔ String?
-
getter/setter pair
- nameLocalized ↔ String?
-
getter/setter pair
- phoneCode ↔ String?
-
getter/setter pair
- phoneNumberLength ↔ int?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited